@@ -17,7 +17,7 @@
  * Boston, MA  02110-1301, USA.
  */
 
-#include "config.h"
+#include "config-miners.h"
 
 #include <string.h>
 #include <ctype.h>
@@ -311,15 +311,14 @@ get_gps_coordinate (ExifData *exif,
 	if (entry && refentry) {
 		ExifByteOrder order;
 		ExifRational degrees, minutes, seconds;
+		gchar buf[G_ASCII_DTOSTR_BUF_SIZE];
 		gfloat f;
-		gchar ref;
 
 		if (entry->size == 24) {
 			order = exif_data_get_byte_order (exif);
 			degrees = exif_get_rational (entry->data, order);
 			minutes = exif_get_rational (entry->data + 8, order);
 			seconds = exif_get_rational (entry->data + 16, order);
-			ref = exif_get_short (refentry->data, order);
 
 			/* Avoid ridiculous values */
 			if (degrees.denominator == 0 ||
@@ -332,11 +331,17 @@ get_gps_coordinate (ExifData *exif,
 				(gdouble) minutes.numerator / (minutes.denominator * 60) +
 				(gdouble) seconds.numerator / (seconds.denominator * 60 * 60);
 
-			if (ref == 'S' || ref == 'W') {
-				f = -1 * f;
+			if (refentry->format == EXIF_FORMAT_ASCII && (refentry->size == 2)) {
+				// following Exif Version 2.2 specs
+				if (refentry->data[0] == 'S' || refentry->data[0] == 'W') {
+					f = -1 * f;
+				}
+			} else {
+				g_error("Invalid GPS Ref entry!");
+				return NULL;
 			}
 
-			return g_strdup_printf ("%f", f);
+			return g_strdup (g_ascii_dtostr (buf, sizeof (buf), (gdouble) f));
 		} else {
 			gchar buf[25] = { 0 };
 
@@ -376,6 +381,7 @@ get_gps_altitude (ExifData *exif,
 	if (entry) {
 		ExifByteOrder order;
 		ExifRational c;
+		gchar buf[G_ASCII_DTOSTR_BUF_SIZE];
 		gfloat f;
 
 		order = exif_data_get_byte_order (exif);
@@ -397,7 +403,7 @@ get_gps_altitude (ExifData *exif,
 				f = -1 * f;
 			}
 		}
-		return g_strdup_printf ("%f", f);
+		return g_strdup (g_ascii_dtostr (buf, sizeof (buf), (gdouble) f));
 	}
 
 	return NULL;
@@ -419,6 +425,39 @@ get_int (ExifData *exif,
 	return -1;
 }
 
+static gboolean
+get_double (ExifData *exif,
+            ExifTag   tag,
+            gdouble  *val)
+{
+	ExifEntry *entry = exif_data_get_entry (exif, tag);
+
+	if (entry) {
+		ExifByteOrder order;
+		ExifRational value;
+
+		order = exif_data_get_byte_order (exif);
+		value = exif_get_rational (entry->data, order);
+
+		*val = (gdouble) value.numerator / (gdouble) value.denominator;
+		return TRUE;
+	}
+
+	return FALSE;
+}
+
+static gchar *
+get_double_str (ExifData *exif,
+                ExifTag   tag)
+{
+	gchar buf[G_ASCII_DTOSTR_BUF_SIZE];
+	gdouble value;
+
+	if (!get_double (exif, tag, &value))
+		return NULL;
+
+	return g_strdup (g_ascii_dtostr (buf, sizeof(buf), value));
+}
 
 static gchar *
 get_value (ExifData *exif,
@@ -540,7 +579,7 @@ parse_exif (const unsigned char *buffer,
 	if(!data->gps_longitude)
 		data->gps_longitude = get_gps_coordinate (exif, EXIF_TAG_GPS_LONGITUDE, EXIF_TAG_GPS_LONGITUDE_REF);
 	if(!data->gps_direction)
-		data->gps_direction = get_value (exif, EXIF_TAG_GPS_IMG_DIRECTION);
+		data->gps_direction = get_double_str (exif, EXIF_TAG_GPS_IMG_DIRECTION);
 
 	exif_data_free (exif);
 #endif /* HAVE_LIBEXIF */
