@@ -33,17 +33,16 @@
 
 #include "tracker-config.h"
 
-#define CONFIG_SCHEMA "org.freedesktop.Tracker.Miner.Files"
+#define CONFIG_SCHEMA "org.freedesktop.Tracker3.Miner.Files"
 #define CONFIG_PATH   "/org/freedesktop/tracker/miner/files/"
 
 /* Default values */
-#define DEFAULT_VERBOSITY                        0
-#define DEFAULT_SCHED_IDLE                       1
 #define DEFAULT_INITIAL_SLEEP                    15       /* 0->1000 */
 #define DEFAULT_ENABLE_MONITORS                  TRUE
 #define DEFAULT_THROTTLE                         0        /* 0->20 */
 #define DEFAULT_INDEX_REMOVABLE_DEVICES          FALSE
 #define DEFAULT_INDEX_OPTICAL_DISCS              FALSE
+#define DEFAULT_INDEX_APPLICATIONS               TRUE
 #define DEFAULT_INDEX_ON_BATTERY                 FALSE
 #define DEFAULT_INDEX_ON_BATTERY_FIRST_TIME      TRUE
 #define DEFAULT_LOW_DISK_SPACE_LIMIT             1        /* 0->100 / -1 */
@@ -99,8 +98,6 @@ enum {
 	PROP_0,
 
 	/* General */
-	PROP_VERBOSITY,
-	PROP_SCHED_IDLE,
 	PROP_INITIAL_SLEEP,
 
 	/* Monitors */
@@ -139,22 +136,6 @@ tracker_config_class_init (TrackerConfigClass *klass)
 	object_class->constructed  = config_constructed;
 
 	/* General */
-	g_object_class_install_property (object_class,
-	                                 PROP_VERBOSITY,
-	                                 g_param_spec_enum ("verbosity",
-	                                                    "Log verbosity",
-	                                                    "Log verbosity (0=errors, 1=minimal, 2=detailed, 3=debug)",
-	                                                    TRACKER_TYPE_VERBOSITY,
-	                                                    DEFAULT_VERBOSITY,
-	                                                    G_PARAM_READWRITE));
-	g_object_class_install_property (object_class,
-	                                 PROP_SCHED_IDLE,
-	                                 g_param_spec_enum ("sched-idle",
-	                                                    "Scheduler priority when idle",
-	                                                    "Scheduler priority when idle (0=always, 1=first-index, 2=never)",
-	                                                    TRACKER_TYPE_SCHED_IDLE,
-	                                                    DEFAULT_SCHED_IDLE,
-	                                                    G_PARAM_READWRITE));
 	g_object_class_install_property (object_class,
 	                                 PROP_INITIAL_SLEEP,
 	                                 g_param_spec_int ("initial-sleep",
@@ -163,7 +144,7 @@ tracker_config_class_init (TrackerConfigClass *klass)
 	                                                   0,
 	                                                   1000,
 	                                                   DEFAULT_INITIAL_SLEEP,
-	                                                   G_PARAM_READWRITE));
+	                                                   G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 	/* Monitors */
 	g_object_class_install_property (object_class,
@@ -172,7 +153,7 @@ tracker_config_class_init (TrackerConfigClass *klass)
 	                                                       "Enable monitors",
 	                                                       "Set to false to completely disable any monitoring",
 	                                                       DEFAULT_ENABLE_MONITORS,
-	                                                       G_PARAM_READWRITE));
+	                                                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 	/* Indexing */
 	g_object_class_install_property (object_class,
@@ -183,21 +164,21 @@ tracker_config_class_init (TrackerConfigClass *klass)
 	                                                   0,
 	                                                   20,
 	                                                   DEFAULT_THROTTLE,
-	                                                   G_PARAM_READWRITE));
+	                                                   G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 	g_object_class_install_property (object_class,
 	                                 PROP_INDEX_ON_BATTERY,
 	                                 g_param_spec_boolean ("index-on-battery",
 	                                                       "Index on battery",
 	                                                       "Set to true to index while running on battery",
 	                                                       DEFAULT_INDEX_ON_BATTERY,
-	                                                       G_PARAM_READWRITE));
+	                                                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 	g_object_class_install_property (object_class,
 	                                 PROP_INDEX_ON_BATTERY_FIRST_TIME,
 	                                 g_param_spec_boolean ("index-on-battery-first-time",
 	                                                       "Index on battery first time",
 	                                                       "Set to true to index while running on battery for the first time only",
 	                                                       DEFAULT_INDEX_ON_BATTERY_FIRST_TIME,
-	                                                       G_PARAM_READWRITE));
+	                                                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 	g_object_class_install_property (object_class,
 	                                 PROP_INDEX_REMOVABLE_DEVICES,
 	                                 g_param_spec_boolean ("index-removable-devices",
@@ -205,7 +186,7 @@ tracker_config_class_init (TrackerConfigClass *klass)
 	                                                       "Set to true to enable traversing mounted directories for removable devices\n"
 	                                                       "(this includes optical discs)",
 	                                                       DEFAULT_INDEX_REMOVABLE_DEVICES,
-	                                                       G_PARAM_READWRITE));
+	                                                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 	g_object_class_install_property (object_class,
 	                                 PROP_INDEX_OPTICAL_DISCS,
 	                                 g_param_spec_boolean ("index-optical-discs",
@@ -213,7 +194,7 @@ tracker_config_class_init (TrackerConfigClass *klass)
 	                                                       "Set to true to enable traversing CDs, DVDs, and generally optical media\n"
 	                                                       "(if removable devices are not indexed, optical discs won't be either)",
 	                                                       DEFAULT_INDEX_OPTICAL_DISCS,
-	                                                       G_PARAM_READWRITE));
+	                                                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 	g_object_class_install_property (object_class,
 	                                 PROP_LOW_DISK_SPACE_LIMIT,
 	                                 g_param_spec_int ("low-disk-space-limit",
@@ -223,7 +204,7 @@ tracker_config_class_init (TrackerConfigClass *klass)
 	                                                   -1,
 	                                                   100,
 	                                                   DEFAULT_LOW_DISK_SPACE_LIMIT,
-	                                                   G_PARAM_READWRITE));
+	                                                   G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 	g_object_class_install_property (object_class,
 	                                 PROP_INDEX_RECURSIVE_DIRECTORIES,
 	                                 g_param_spec_boxed ("index-recursive-directories",
@@ -240,7 +221,7 @@ tracker_config_class_init (TrackerConfigClass *klass)
 	                                                     "   &VIDEOS\n"
 	                                                     " If $HOME is the default below, it is because $HOME/.config/user-dirs.default was missing.",
 	                                                     G_TYPE_STRV,
-	                                                     G_PARAM_READWRITE));
+	                                                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 	g_object_class_install_property (object_class,
 	                                 PROP_INDEX_SINGLE_DIRECTORIES,
 	                                 g_param_spec_boxed ("index-single-directories",
@@ -248,28 +229,28 @@ tracker_config_class_init (TrackerConfigClass *klass)
 	                                                     " List of directories to index but not sub-directories for changes (separator=;)\n"
 	                                                     " Special values used for IndexRecursiveDirectories can also be used here",
 	                                                     G_TYPE_STRV,
-	                                                     G_PARAM_READWRITE));
+	                                                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 	g_object_class_install_property (object_class,
 	                                 PROP_IGNORED_DIRECTORIES,
 	                                 g_param_spec_boxed ("ignored-directories",
 	                                                     "Ignored directories",
 	                                                     " List of directories to NOT crawl for indexing (separator=;)",
 	                                                     G_TYPE_STRV,
-	                                                     G_PARAM_READWRITE));
+	                                                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 	g_object_class_install_property (object_class,
 	                                 PROP_IGNORED_DIRECTORIES_WITH_CONTENT,
 	                                 g_param_spec_boxed ("ignored-directories-with-content",
 	                                                     "Ignored directories with content",
 	                                                     " List of directories to NOT crawl for indexing based on child files (separator=;)",
 	                                                     G_TYPE_STRV,
-	                                                     G_PARAM_READWRITE));
+	                                                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 	g_object_class_install_property (object_class,
 	                                 PROP_IGNORED_FILES,
 	                                 g_param_spec_boxed ("ignored-files",
 	                                                     "Ignored files",
 	                                                     " List of files to NOT index (separator=;)",
 	                                                     G_TYPE_STRV,
-	                                                     G_PARAM_READWRITE));
+	                                                     G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 	g_object_class_install_property (object_class,
 	                                 PROP_CRAWLING_INTERVAL,
 	                                 g_param_spec_int ("crawling-interval",
@@ -282,7 +263,7 @@ tracker_config_class_init (TrackerConfigClass *klass)
 	                                                   -2,
 	                                                   365,
 	                                                   DEFAULT_CRAWLING_INTERVAL,
-	                                                   G_PARAM_READWRITE));
+	                                                   G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 	g_object_class_install_property (object_class,
 	                                 PROP_REMOVABLE_DAYS_THRESHOLD,
 	                                 g_param_spec_int ("removable-days-threshold",
@@ -293,7 +274,7 @@ tracker_config_class_init (TrackerConfigClass *klass)
 	                                                   0,
 	                                                   365,
 	                                                   DEFAULT_REMOVABLE_DAYS_THRESHOLD,
-	                                                   G_PARAM_READWRITE));
+	                                                   G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
 	/* Writeback */
 	g_object_class_install_property (object_class,
@@ -302,7 +283,7 @@ tracker_config_class_init (TrackerConfigClass *klass)
 	                                                       "Enable Writeback",
 	                                                       "Set to false to disable writeback",
 	                                                       DEFAULT_ENABLE_WRITEBACK,
-	                                                       G_PARAM_READWRITE));
+	                                                       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 }
 
 static void
@@ -323,9 +304,6 @@ config_set_property (GObject      *object,
 		/* NOTE: We handle these because we have to be able
 		 * to save these based on command line overrides.
 		 */
-	case PROP_VERBOSITY:
-		tracker_config_set_verbosity (config, g_value_get_enum (value));
-		break;
 	case PROP_INITIAL_SLEEP:
 		tracker_config_set_initial_sleep (config, g_value_get_int (value));
 		break;
@@ -402,12 +380,6 @@ config_get_property (GObject    *object,
 
 	switch (param_id) {
 		/* General */
-	case PROP_VERBOSITY:
-		g_value_set_enum (value, tracker_config_get_verbosity (config));
-		break;
-	case PROP_SCHED_IDLE:
-		g_value_set_enum (value, tracker_config_get_sched_idle (config));
-		break;
 	case PROP_INITIAL_SLEEP:
 		g_value_set_int (value, tracker_config_get_initial_sleep (config));
 		break;
@@ -650,8 +622,7 @@ config_constructed (GObject *object)
 	 *
 	 * NOTE: We need this. If we don't we can't have local
 	 * settings which are *NOT* stored in the GSettings database.
-	 * We need this for overriding things like verbosity on start
-	 * up.
+	 * We need this for overriding things on start up.
 	 */
 	if (G_LIKELY (!g_getenv ("TRACKER_USE_CONFIG_FILES"))) {
 		g_settings_delay (settings);
@@ -659,11 +630,10 @@ config_constructed (GObject *object)
 
 	/* Set up bindings:
 	 *
-	 * What's interesting here is that 'verbosity' and
-	 * 'initial-sleep' are command line arguments that can be
-	 * overridden, so we don't update the config when we set them
-	 * from main() because it's a session configuration only, not
-	 * a permanent one. To do this we use the flag
+	 * What's interesting here is that 'initial-sleep' is a
+	 * command line argument that can be overridden, so we don't update the
+	 * config when we set it from main() because it's a session configuration
+	 * only, not a permanent one. To do this we use the flag
 	 * G_SETTINGS_BIND_GET_NO_CHANGES.
 	 *
 	 * For the other settings, we don't bind the
@@ -675,8 +645,6 @@ config_constructed (GObject *object)
 	 * file for convenience. But this is only necessary if the
 	 * config is different to the default.
 	 */
-	g_settings_bind (settings, "verbosity", object, "verbosity", G_SETTINGS_BIND_GET | G_SETTINGS_BIND_GET_NO_CHANGES);
-	g_settings_bind (settings, "sched-idle", object, "sched-idle", G_SETTINGS_BIND_GET);
 	g_settings_bind (settings, "initial-sleep", object, "initial-sleep", G_SETTINGS_BIND_GET | G_SETTINGS_BIND_GET_NO_CHANGES);
 	g_settings_bind (settings, "throttle", object, "throttle", G_SETTINGS_BIND_GET);
 	g_settings_bind (settings, "low-disk-space-limit", object, "low-disk-space-limit", G_SETTINGS_BIND_GET);
@@ -741,22 +709,6 @@ tracker_config_new (void)
 	return config;
 }
 
-gint
-tracker_config_get_verbosity (TrackerConfig *config)
-{
-	g_return_val_if_fail (TRACKER_IS_CONFIG (config), DEFAULT_VERBOSITY);
-
-	return g_settings_get_enum (G_SETTINGS (config), "verbosity");
-}
-
-gint
-tracker_config_get_sched_idle (TrackerConfig *config)
-{
-	g_return_val_if_fail (TRACKER_IS_CONFIG (config), DEFAULT_SCHED_IDLE);
-
-	return g_settings_get_enum (G_SETTINGS (config), "sched-idle");
-}
-
 gint
 tracker_config_get_initial_sleep (TrackerConfig *config)
 {
@@ -821,6 +773,14 @@ tracker_config_get_index_optical_discs (TrackerConfig *config)
 	return g_settings_get_boolean (G_SETTINGS (config), "index-optical-discs");
 }
 
+gboolean
+tracker_config_get_index_applications (TrackerConfig *config)
+{
+	g_return_val_if_fail (TRACKER_IS_CONFIG (config), DEFAULT_INDEX_APPLICATIONS);
+
+	return g_settings_get_boolean (G_SETTINGS (config), "index-applications");
+}
+
 gint
 tracker_config_get_low_disk_space_limit (TrackerConfig *config)
 {
@@ -905,16 +865,6 @@ tracker_config_get_removable_days_threshold (TrackerConfig *config)
 	return g_settings_get_int (G_SETTINGS (config), "removable-days-threshold");
 }
 
-void
-tracker_config_set_verbosity (TrackerConfig *config,
-                              gint           value)
-{
-	g_return_if_fail (TRACKER_IS_CONFIG (config));
-
-	g_settings_set_enum (G_SETTINGS (config), "verbosity", value);
-	g_object_notify (G_OBJECT (config), "verbosity");
-}
-
 void
 tracker_config_set_initial_sleep (TrackerConfig *config,
                                   gint           value)
