@@ -52,13 +52,12 @@
 
 #define SECONDS_PER_DAY 60 * 60 * 24
 
-#define DBUS_NAME_SUFFIX "Tracker1.Miner.Files"
-#define DBUS_PATH "/org/freedesktop/Tracker1/Miner/Files"
+#define DBUS_NAME_SUFFIX "Tracker3.Miner.Files"
+#define DBUS_PATH "/org/freedesktop/Tracker3/Miner/Files"
 #define LOCALE_FILENAME "locale-for-miner-apps.txt"
 
 static GMainLoop *main_loop;
 
-static gint verbosity = -1;
 static gint initial_sleep = -1;
 static gboolean no_daemon;
 static gchar *eligible;
@@ -68,11 +67,6 @@ static gboolean do_crawling = FALSE;
 static gchar *domain_ontology_name = NULL;
 
 static GOptionEntry entries[] = {
-	{ "verbosity", 'v', 0,
-	  G_OPTION_ARG_INT, &verbosity,
-	  N_("Logging, 0 = errors only, "
-	     "1 = minimal, 2 = detailed and 3 = debug (default=0)"),
-	  NULL },
 	{ "initial-sleep", 's', 0,
 	  G_OPTION_ARG_INT, &initial_sleep,
 	  N_("Initial sleep time in seconds, "
@@ -98,29 +92,31 @@ static GOptionEntry entries[] = {
 };
 
 static void
-sanity_check_option_values (TrackerConfig *config)
+log_option_values (TrackerConfig *config)
 {
-	g_message ("General options:");
-	g_message ("  Verbosity  ............................  %d",
-	           tracker_config_get_verbosity (config));
-	g_message ("  Sched Idle  ...........................  %d",
-	           tracker_config_get_sched_idle (config));
-	g_message ("  Initial Sleep  ........................  %d",
-	           tracker_config_get_initial_sleep (config));
+#ifdef G_ENABLE_DEBUG
+	if (TRACKER_DEBUG_CHECK (CONFIG)) {
+		g_message ("General options:");
+		g_message ("  Initial Sleep  ........................  %d",
+		           tracker_config_get_initial_sleep (config));
+		g_message ("  Writeback  ............................  %s",
+		           tracker_config_get_enable_writeback (config) ? "yes" : "no");
 
-	g_message ("Indexer options:");
-	g_message ("  Throttle level  .......................  %d",
-	           tracker_config_get_throttle (config));
-	g_message ("  Indexing while on battery  ............  %s (first time only = %s)",
-	           tracker_config_get_index_on_battery (config) ? "yes" : "no",
-	           tracker_config_get_index_on_battery_first_time (config) ? "yes" : "no");
+		g_message ("Indexer options:");
+		g_message ("  Throttle level  .......................  %d",
+		           tracker_config_get_throttle (config));
+		g_message ("  Indexing while on battery  ............  %s (first time only = %s)",
+		           tracker_config_get_index_on_battery (config) ? "yes" : "no",
+		           tracker_config_get_index_on_battery_first_time (config) ? "yes" : "no");
 
-	if (tracker_config_get_low_disk_space_limit (config) == -1) {
-		g_message ("  Low disk space limit  .................  Disabled");
-	} else {
-		g_message ("  Low disk space limit  .................  %d%%",
-		           tracker_config_get_low_disk_space_limit (config));
+		if (tracker_config_get_low_disk_space_limit (config) == -1) {
+			g_message ("  Low disk space limit  .................  Disabled");
+		} else {
+			g_message ("  Low disk space limit  .................  %d%%",
+			           tracker_config_get_low_disk_space_limit (config));
+		}
 	}
+#endif
 }
 
 static void
@@ -130,10 +126,10 @@ miner_reset_applications (TrackerMiner *miner)
 	GError *error = NULL;
 
 	sparql =
-		"DELETE { GRAPH <" TRACKER_OWN_GRAPH_URN "> { ?icon a rdfs:Resource } } "
-		"WHERE { GRAPH <" TRACKER_OWN_GRAPH_URN "> { ?app a nfo:SoftwareApplication; nfo:softwareIcon ?icon } } "
-		"DELETE { GRAPH <" TRACKER_OWN_GRAPH_URN "> { ?app nie:dataSource <" TRACKER_PREFIX_TRACKER "extractor-data-source> } } "
-		"WHERE { GRAPH <" TRACKER_OWN_GRAPH_URN "> { ?app a nfo:SoftwareApplication } }";
+		"DELETE { ?icon a rdfs:Resource } "
+		"WHERE { ?app a nfo:SoftwareApplication; nfo:softwareIcon ?icon } "
+		"DELETE { ?app nie:dataSource <" TRACKER_PREFIX_TRACKER "extractor-data-source> } "
+		"WHERE { ?app a nfo:SoftwareApplication } ";
 
 	/* Execute a sync update, we don't want the apps miner to start before
 	 * we finish this. */
@@ -149,15 +145,29 @@ miner_reset_applications (TrackerMiner *miner)
 	}
 }
 
+static GFile *
+get_cache_dir (TrackerDomainOntology *domain_ontology)
+{
+	GFile *cache;
+
+	cache = tracker_domain_ontology_get_cache (domain_ontology);
+	return g_file_get_child (cache, "files");
+}
+
 static void
-save_current_locale (void)
+save_current_locale (TrackerDomainOntology *domain_ontology)
 {
 	GError *error = NULL;
 	gchar *locale = tracker_locale_get (TRACKER_LOCALE_LANGUAGE);
-	gchar *locale_file = g_build_filename (g_get_user_cache_dir (), "tracker", LOCALE_FILENAME, NULL);
+	GFile *cache = get_cache_dir (domain_ontology);
+	gchar *cache_path = g_file_get_path (cache);
+	gchar *locale_file;
 
-	g_message ("Saving locale used to index applications");
-	g_message ("  Creating locale file '%s'", locale_file);
+	locale_file = g_build_filename (cache_path, LOCALE_FILENAME, NULL);
+	g_free (cache_path);
+
+	TRACKER_NOTE (CONFIG, g_message ("Saving locale used to index applications"));
+	TRACKER_NOTE (CONFIG, g_message ("  Creating locale file '%s'", locale_file));
 
 	if (locale == NULL) {
 		locale = g_strdup ("");
@@ -174,14 +184,20 @@ save_current_locale (void)
 }
 
 static gboolean
-detect_locale_changed (TrackerMiner *miner)
+detect_locale_changed (TrackerMiner          *miner,
+		       TrackerDomainOntology *domain_ontology)
 {
+	GFile *cache;
+	gchar *cache_path;
 	gchar *locale_file;
 	gchar *previous_locale = NULL;
 	gchar *current_locale;
 	gboolean changed;
 
-	locale_file = g_build_filename (g_get_user_cache_dir (), "tracker", LOCALE_FILENAME, NULL);
+	cache = get_cache_dir (domain_ontology);
+	cache_path = g_file_get_path (cache);
+	locale_file = g_build_filename (cache_path, LOCALE_FILENAME, NULL);
+	g_free (cache_path);
 
 	if (G_LIKELY (g_file_test (locale_file, G_FILE_TEST_EXISTS))) {
 		gchar *contents;
@@ -200,7 +216,7 @@ detect_locale_changed (TrackerMiner *miner)
 			g_critical ("  Could not get content of file '%s'", locale_file);
 		}
 	} else {
-		g_message ("  Could not find locale file:'%s'", locale_file);
+		TRACKER_NOTE (CONFIG, g_message ("  Could not find locale file:'%s'", locale_file));
 	}
 
 	g_free (locale_file);
@@ -210,11 +226,11 @@ detect_locale_changed (TrackerMiner *miner)
 	/* Note that having both to NULL is actually valid, they would default
 	 * to the unicode collation without locale-specific stuff. */
 	if (g_strcmp0 (previous_locale, current_locale) != 0) {
-		g_message ("Locale change detected from '%s' to '%s'...",
-		           previous_locale, current_locale);
+		TRACKER_NOTE (CONFIG, g_message ("Locale change detected from '%s' to '%s'...",
+		                      previous_locale, current_locale));
 		changed = TRUE;
 	} else {
-		g_message ("Current and previous locales match: '%s'", previous_locale);
+		TRACKER_NOTE (CONFIG, g_message ("Current and previous locales match: '%s'", previous_locale));
 		changed = FALSE;
 	}
 
@@ -222,7 +238,7 @@ detect_locale_changed (TrackerMiner *miner)
 	g_free (previous_locale);
 
 	if (changed) {
-		g_message ("Resetting nfo:Software due to locale change...");
+		TRACKER_NOTE (CONFIG, g_message ("Resetting nfo:Software due to locale change..."));
 		miner_reset_applications (miner);
 	}
 
@@ -250,10 +266,9 @@ signal_handler (gpointer user_data)
 		/* Fall through */
 	default:
 		if (g_strsignal (signo)) {
-			g_print ("\n");
-			g_print ("Received signal:%d->'%s'\n",
-			         signo,
-			         g_strsignal (signo));
+			g_message ("Received signal:%d->'%s'",
+			           signo,
+			           g_strsignal (signo));
 		}
 		break;
 	}
@@ -287,7 +302,7 @@ initialize_priority_and_scheduling (void)
 	 * Stupid...
 	 */
 
-	g_message ("Setting priority nice level to 19");
+	TRACKER_NOTE (CONFIG, g_message ("Setting priority nice level to 19"));
 
 	errno = 0;
 	if (nice (19) == -1 && errno != 0) {
@@ -299,23 +314,24 @@ initialize_priority_and_scheduling (void)
 }
 
 static gboolean
-should_crawl (TrackerConfig *config,
-              gboolean      *forced)
+should_crawl (TrackerMinerFiles *miner_files,
+              TrackerConfig     *config,
+              gboolean          *forced)
 {
 	gint crawling_interval;
 
 	crawling_interval = tracker_config_get_crawling_interval (config);
 
-	g_message ("Checking whether to crawl file system based on configured crawling interval:");
+	TRACKER_NOTE (CONFIG, g_message ("Checking whether to crawl file system based on configured crawling interval:"));
 
 	if (crawling_interval == -2) {
-		g_message ("  Disabled");
+		TRACKER_NOTE (CONFIG, g_message ("  Disabled"));
 		return FALSE;
 	} else if (crawling_interval == -1) {
-		g_message ("  Maybe (depends on a clean last shutdown)");
+		TRACKER_NOTE (CONFIG, g_message ("  Maybe (depends on a clean last shutdown)"));
 		return TRUE;
 	} else if (crawling_interval == 0) {
-		g_message ("  Forced");
+		TRACKER_NOTE (CONFIG, g_message ("  Forced"));
 
 		if (forced) {
 			*forced = TRUE;
@@ -325,7 +341,7 @@ should_crawl (TrackerConfig *config,
 	} else {
 		guint64 then, now;
 
-		then = tracker_miner_files_get_last_crawl_done ();
+		then = tracker_miner_files_get_last_crawl_done (miner_files);
 
 		if (then < 1) {
 			return TRUE;
@@ -334,11 +350,11 @@ should_crawl (TrackerConfig *config,
 		now = (guint64) time (NULL);
 
 		if (now < then + (crawling_interval * SECONDS_PER_DAY)) {
-			g_message ("  Postponed");
+			TRACKER_NOTE (CONFIG, g_message ("  Postponed"));
 			return FALSE;
 		} else {
-			g_message ("  (More than) %d days after last crawling, enabled", crawling_interval);
-			return FALSE;
+			TRACKER_NOTE (CONFIG, g_message ("  (More than) %d days after last crawling, enabled", crawling_interval));
+			return TRUE;
 		}
 	}
 }
@@ -347,7 +363,7 @@ static void
 miner_do_start (TrackerMiner *miner)
 {
 	if (!tracker_miner_is_started (miner)) {
-		g_message ("Starting filesystem miner...");
+		g_debug ("Starting filesystem miner...");
 		tracker_miner_start (miner);
 	}
 }
@@ -389,8 +405,8 @@ miner_start (TrackerMiner  *miner,
 		return;
 	}
 
-	g_debug ("Performing initial sleep of %d seconds",
-	         initial_sleep);
+	g_message ("Performing initial sleep of %d seconds",
+	           initial_sleep);
 	miners_timeout_id = g_timeout_add_seconds (initial_sleep,
 	                                           miner_start_idle_cb,
 	                                           miner);
@@ -411,7 +427,8 @@ miner_finished_cb (TrackerMinerFS *fs,
 	        total_files_found);
 
 	if (do_crawling) {
-		tracker_miner_files_set_last_crawl_done (TRUE);
+		tracker_miner_files_set_last_crawl_done (TRACKER_MINER_FILES (fs),
+							 TRUE);
 	}
 
 	/* We're not sticking around for file updates, so stop
@@ -670,56 +687,14 @@ check_eligible (void)
 }
 
 static gboolean
-store_is_available (void)
-{
-	GDBusConnection *connection;
-	GDBusProxy *proxy;
-	gchar *name_owner;
-
-	connection = g_bus_get_sync (TRACKER_IPC_BUS, NULL, NULL);
-
-	if (!connection) {
-		return FALSE;
-	}
-
-	proxy = g_dbus_proxy_new_sync (connection,
-	                               G_DBUS_PROXY_FLAGS_DO_NOT_AUTO_START,
-	                               NULL,
-	                               "org.freedesktop.Tracker1",
-	                               "/org/freedesktop/Tracker1/Status",
-	                               "org.freedesktop.Tracker1.Status",
-	                               NULL, NULL);
-
-	if (!proxy) {
-		g_object_unref (connection);
-		return FALSE;
-	}
-
-	name_owner = g_dbus_proxy_get_name_owner (proxy);
-
-	g_object_unref (connection);
-	g_object_unref (proxy);
-
-	if (name_owner) {
-		g_free (name_owner);
-		return TRUE;
-	}
-
-	return FALSE;
-}
-
-static gboolean
-miner_needs_check (TrackerMiner *miner,
-                   gboolean      store_available)
+miner_needs_check (TrackerMiner *miner)
 {
 	/* Reasons to not mark ourselves as cleanly shutdown include:
 	 *
 	 * 1. Still crawling or with files to process in our queues.
 	 * 2. We crash (out of our control usually anyway).
 	 * 3. At least one of the miners is PAUSED, we have
-	 *    to exclude the situations where the miner is
-	 *    exclusively paused due to the store not being
-	 *    available, but the miner is actually done.
+	 *    to exclude the situations where the miner is actually done.
 	 */
 	if (!tracker_miner_is_paused (miner)) {
 		if (tracker_miner_fs_has_items_to_process (TRACKER_MINER_FS (miner))) {
@@ -735,15 +710,8 @@ miner_needs_check (TrackerMiner *miner,
 		/* We consider the miner finished */
 		return FALSE;
 	} else {
-		if (store_available) {
-			/* Paused for other reasons, so probably not done */
-			return TRUE;
-		} else {
-			/* Check whether there are more pause
-			 * reasons than the store being out.
-			 */
-			return tracker_miner_is_paused (miner);
-		}
+		/* Paused for other reasons, so probably not done */
+		return TRUE;
 	}
 }
 
@@ -753,9 +721,64 @@ on_domain_vanished (GDBusConnection *connection,
                     gpointer         user_data)
 {
 	GMainLoop *loop = user_data;
+	g_message ("Domain %s vanished: quitting now.", name);
 	g_main_loop_quit (loop);
 }
 
+TrackerSparqlConnectionFlags
+get_fts_connection_flags (void)
+{
+	TrackerSparqlConnectionFlags flags = 0;
+	TrackerFTSConfig *fts_config;
+
+	fts_config = tracker_fts_config_new ();
+
+	if (tracker_fts_config_get_enable_stemmer (fts_config))
+		flags |= TRACKER_SPARQL_CONNECTION_FLAGS_FTS_ENABLE_STEMMER;
+	if (tracker_fts_config_get_enable_unaccent (fts_config))
+		flags |= TRACKER_SPARQL_CONNECTION_FLAGS_FTS_ENABLE_UNACCENT;
+	if (tracker_fts_config_get_ignore_numbers (fts_config))
+		flags |= TRACKER_SPARQL_CONNECTION_FLAGS_FTS_IGNORE_NUMBERS;
+	if (tracker_fts_config_get_ignore_stop_words (fts_config))
+		flags |= TRACKER_SPARQL_CONNECTION_FLAGS_FTS_ENABLE_STOP_WORDS;
+
+	g_object_unref (fts_config);
+
+	return flags;
+}
+
+static gboolean
+setup_connection_and_endpoint (TrackerDomainOntology    *domain,
+                               GDBusConnection          *connection,
+                               TrackerSparqlConnection **sparql_conn,
+                               TrackerEndpointDBus     **endpoint,
+                               GError                  **error)
+{
+	GFile *store, *ontology;
+
+	store = get_cache_dir (domain);
+	ontology = tracker_domain_ontology_get_ontology (domain);
+	*sparql_conn = tracker_sparql_connection_new (get_fts_connection_flags (),
+	                                              store,
+	                                              ontology,
+	                                              NULL,
+	                                              error);
+	g_object_unref (store);
+
+	if (!*sparql_conn)
+		return FALSE;
+
+	*endpoint = tracker_endpoint_dbus_new (*sparql_conn,
+	                                       connection,
+	                                       NULL,
+	                                       NULL,
+	                                       error);
+	if (!*endpoint)
+		return FALSE;
+
+	return TRUE;
+}
+
 int
 main (gint argc, gchar *argv[])
 {
@@ -764,13 +787,14 @@ main (gint argc, gchar *argv[])
 	TrackerMinerFilesIndex *miner_files_index;
 	GOptionContext *context;
 	GError *error = NULL;
-	gchar *log_filename = NULL;
 	gboolean do_mtime_checking;
 	gboolean force_mtime_checking = FALSE;
-	gboolean store_available;
 	TrackerMinerProxy *proxy;
 	GDBusConnection *connection;
-	gchar *dbus_domain_name, *dbus_name;
+	TrackerSparqlConnection *sparql_conn;
+	TrackerEndpointDBus *endpoint;
+	TrackerDomainOntology *domain_ontology;
+	gchar *domain_name, *dbus_name;
 
 	main_loop = NULL;
 
@@ -783,6 +807,9 @@ main (gint argc, gchar *argv[])
 	/* Set timezone info */
 	tzset ();
 
+	/* This makes sure we don't steal all the system's resources */
+	initialize_priority_and_scheduling ();
+
 	/* Translators: this messagge will apper immediately after the
 	 * usage string - Usage: COMMAND <THIS_MESSAGE>
 	 */
@@ -808,20 +835,14 @@ main (gint argc, gchar *argv[])
 		return EXIT_SUCCESS;
 	}
 
-	tracker_sparql_connection_set_domain (domain_ontology_name);
-
-	tracker_load_domain_config (domain_ontology_name, &dbus_domain_name, &error);
-
-	if (error != NULL) {
+	domain_ontology = tracker_domain_ontology_new (domain_ontology_name, NULL, &error);
+	if (error) {
 		g_critical ("Could not load domain ontology '%s': %s",
 		            domain_ontology_name, error->message);
 		g_error_free (error);
 		return EXIT_FAILURE;
 	}
 
-	/* This makes sure we don't steal all the system's resources */
-	initialize_priority_and_scheduling ();
-
 	connection = g_bus_get_sync (TRACKER_IPC_BUS, NULL, &error);
 	if (error) {
 		g_critical ("Could not create DBus connection: %s\n",
@@ -833,54 +854,58 @@ main (gint argc, gchar *argv[])
 	/* Initialize logging */
 	config = tracker_config_new ();
 
-	if (verbosity > -1) {
-		tracker_config_set_verbosity (config, verbosity);
-	}
-
 	if (initial_sleep > -1) {
 		tracker_config_set_initial_sleep (config, initial_sleep);
 	}
 
-	tracker_log_init (tracker_config_get_verbosity (config),
-	                  &log_filename);
-	if (log_filename) {
-		g_message ("Using log file:'%s'", log_filename);
-		g_free (log_filename);
-	}
-
-	sanity_check_option_values (config);
+	log_option_values (config);
 
 	main_loop = g_main_loop_new (NULL, FALSE);
 
-	if (domain_ontology_name) {
+	if (domain_ontology && domain_ontology_name) {
 		/* If we are running for a specific domain, we tie the lifetime of this
 		 * process to the domain. For example, if the domain name is
 		 * org.example.MyApp then this tracker-miner-fs process will exit as
 		 * soon as org.example.MyApp exits.
 		 */
-		g_bus_watch_name_on_connection (connection, dbus_domain_name,
+		domain_name = tracker_domain_ontology_get_domain (domain_ontology, NULL);
+		g_bus_watch_name_on_connection (connection, domain_name,
 		                                G_BUS_NAME_WATCHER_FLAGS_NONE,
 		                                NULL, on_domain_vanished,
 		                                main_loop, NULL);
+		g_free (domain_name);
 	}
 
-	g_message ("Checking if we're running as a daemon:");
-	g_message ("  %s %s",
-	           no_daemon ? "No" : "Yes",
-	           no_daemon ? "(forced by command line)" : "");
+	TRACKER_NOTE (CONFIG, g_message ("Checking if we're running as a daemon:"));
+	TRACKER_NOTE (CONFIG, g_message ("  %s %s",
+	                      no_daemon ? "No" : "Yes",
+	                      no_daemon ? "(forced by command line)" : ""));
+
+	if (!setup_connection_and_endpoint (domain_ontology,
+	                                    connection,
+	                                    &sparql_conn,
+	                                    &endpoint,
+	                                    &error)) {
+
+		g_critical ("Could not create store/endpoint: %s",
+		            error->message);
+		g_error_free (error);
+
+		return EXIT_FAILURE;
+	}
 
 	/* Create new TrackerMinerFiles object */
-	miner_files = tracker_miner_files_new (config, &error);
+	miner_files = tracker_miner_files_new (sparql_conn, config,
+	                                       domain_ontology_name, &error);
 	if (!miner_files) {
 		g_critical ("Couldn't create new Files miner: '%s'",
 		            error ? error->message : "unknown error");
 		g_object_unref (config);
-		tracker_log_shutdown ();
 		return EXIT_FAILURE;
 	}
 
 	/* If the locales changed, we need to reset some things first */
-	detect_locale_changed (TRACKER_MINER (miner_files));
+	detect_locale_changed (TRACKER_MINER (miner_files), domain_ontology);
 
 	proxy = tracker_miner_proxy_new (miner_files, connection, DBUS_PATH, NULL, &error);
 	if (error) {
@@ -888,7 +913,6 @@ main (gint argc, gchar *argv[])
 		g_error_free (error);
 		g_object_unref (config);
 		g_object_unref (miner_files);
-		tracker_log_shutdown ();
 		return EXIT_FAILURE;
 	}
 
@@ -901,7 +925,6 @@ main (gint argc, gchar *argv[])
 		            error ? error->message : "unknown error");
 		g_object_unref (config);
 		g_object_unref (miner_files);
-		tracker_log_shutdown ();
 		return EXIT_FAILURE;
 	}
 
@@ -911,12 +934,11 @@ main (gint argc, gchar *argv[])
 		g_object_unref (miner_files);
 		tracker_writeback_shutdown ();
 		g_object_unref (config);
-		tracker_log_shutdown ();
 		return EXIT_FAILURE;
 	}
 
 	/* Request DBus name */
-	dbus_name = g_strconcat (dbus_domain_name, ".", DBUS_NAME_SUFFIX, NULL);
+	dbus_name = tracker_domain_ontology_get_domain (domain_ontology, DBUS_NAME_SUFFIX);
 
 	if (!tracker_dbus_request_name (connection, dbus_name, &error)) {
 		g_critical ("Could not request DBus name '%s': %s",
@@ -931,7 +953,8 @@ main (gint argc, gchar *argv[])
 	/* Check if we should crawl and if we should force mtime
 	 * checking based on the config.
 	 */
-	do_crawling = should_crawl (config, &force_mtime_checking);
+	do_crawling = should_crawl (TRACKER_MINER_FILES (miner_files),
+	                            config, &force_mtime_checking);
 
 	/* Get the last shutdown state to see if we need to perform a
 	 * full mtime check against the db or not.
@@ -939,24 +962,24 @@ main (gint argc, gchar *argv[])
 	 * Set to TRUE here in case we crash and miss file system
 	 * events.
 	 */
-	g_message ("Checking whether to force mtime checking during crawling (based on last clean shutdown):");
+	TRACKER_NOTE (CONFIG, g_message ("Checking whether to force mtime checking during crawling (based on last clean shutdown):"));
 
 	/* Override the shutdown state decision based on the config */
 	if (force_mtime_checking) {
 		do_mtime_checking = TRUE;
 	} else {
-		do_mtime_checking = tracker_miner_files_get_need_mtime_check ();
+		do_mtime_checking = tracker_miner_files_get_need_mtime_check (TRACKER_MINER_FILES (miner_files));
 	}
 
-	g_message ("  %s %s",
-	           do_mtime_checking ? "Yes" : "No",
-	           force_mtime_checking ? "(forced from config)" : "");
+	TRACKER_NOTE (CONFIG, g_message ("  %s %s",
+	                      do_mtime_checking ? "Yes" : "No",
+	                      force_mtime_checking ? "(forced from config)" : ""));
 
 	/* Set the need for an mtime check to TRUE so we check in the
 	 * event of a crash, this is changed back on shutdown if
 	 * everything appears to be fine.
 	 */
-	tracker_miner_files_set_need_mtime_check (TRUE);
+	tracker_miner_files_set_need_mtime_check (TRACKER_MINER_FILES (miner_files), TRUE);
 
 	/* Configure files miner */
 	tracker_miner_files_set_mtime_checking (TRACKER_MINER_FILES (miner_files), do_mtime_checking);
@@ -972,14 +995,11 @@ main (gint argc, gchar *argv[])
 	/* Go, go, go! */
 	g_main_loop_run (main_loop);
 
-	g_message ("Shutdown started");
+	g_debug ("Shutdown started");
 
-	store_available = store_is_available ();
-
-	if (miners_timeout_id == 0 &&
-	    !miner_needs_check (miner_files, store_available)) {
-		tracker_miner_files_set_need_mtime_check (FALSE);
-		save_current_locale ();
+	if (miners_timeout_id == 0 && !miner_needs_check (miner_files)) {
+		tracker_miner_files_set_need_mtime_check (TRACKER_MINER_FILES (miner_files), FALSE);
+		save_current_locale (domain_ontology);
 	}
 
 	g_main_loop_unref (main_loop);
@@ -990,11 +1010,9 @@ main (gint argc, gchar *argv[])
 
 	g_object_unref (proxy);
 	g_object_unref (connection);
-
-	g_free (dbus_domain_name);
+	tracker_domain_ontology_unref (domain_ontology);
 
 	tracker_writeback_shutdown ();
-	tracker_log_shutdown ();
 
 	g_print ("\nOK\n\n");
 
