@@ -25,13 +25,12 @@
 #include "tracker-writeback-listener.h"
 #include "tracker-miner-files.h"
 
-#define TRACKER_SERVICE                 "org.freedesktop.Tracker1"
-#define TRACKER_RESOURCES_OBJECT        "/org/freedesktop/Tracker1/Resources"
-#define TRACKER_INTERFACE_RESOURCES     "org.freedesktop.Tracker1.Resources"
+#define TRACKER_SERVICE                 "org.freedesktop.Tracker3"
+#define TRACKER_RESOURCES_OBJECT        "/org/freedesktop/Tracker3/Resources"
+#define TRACKER_INTERFACE_RESOURCES     "org.freedesktop.Tracker3.Resources"
 
 typedef struct {
 	gint32 subject_id;
-	gint32 *types;
 } WritebackEvent;
 
 typedef struct {
@@ -102,11 +101,11 @@ tracker_writeback_listener_class_init (TrackerWritebackListenerClass *klass)
 
 	g_object_class_install_property (object_class,
 	                                 PROP_FILES_MINER,
-	                                 g_param_spec_object ("files_miner",
-	                                                      "files_miner",
+	                                 g_param_spec_object ("files-miner",
+	                                                      "files-miner",
 	                                                      "The FS Miner",
 	                                                      TRACKER_TYPE_MINER_FILES,
-	                                                      G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY));
+	                                                      G_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY | G_PARAM_STATIC_STRINGS));
 }
 
 static void
@@ -154,7 +153,6 @@ writeback_listener_get_property (GObject    *object,
 static void
 free_event (WritebackEvent *event)
 {
-	g_free (event->types);
 	g_free (event);
 }
 
@@ -210,13 +208,7 @@ writeback_listener_initable_init (GInitable    *initable,
 	GError *internal_error = NULL;
 
 	priv = tracker_writeback_listener_get_instance_private (listener);
-
-	priv->connection = tracker_sparql_connection_get (NULL, &internal_error);
-
-	if (internal_error) {
-		g_propagate_error (error, internal_error);
-		return FALSE;
-	}
+	priv->connection = tracker_miner_get_connection (TRACKER_MINER (priv->files_miner));
 
 	priv->d_connection = g_bus_get_sync (TRACKER_IPC_BUS, NULL, &internal_error);
 
@@ -437,8 +429,6 @@ process_event (gpointer user_data)
 	WritebackEvent *event;
 	QueryData *data = NULL;
 	GString *query;
-	gboolean comma = FALSE;
-	gint i;
 
 	priv = tracker_writeback_listener_get_instance_private (self);
 	event = g_queue_pop_head (priv->events);
@@ -453,24 +443,13 @@ process_event (gpointer user_data)
 	 * queries that must be made. tracker:uri() is idd unrelated to
 	 * the other part of the query (and is repeated each result, idd) */
 
-	query = g_string_new ("SELECT ");
-	g_string_append_printf (query, "?resource tracker:uri (%d) { "
-		                       "?resource a rdfs:Class . "
-		                       "FILTER (tracker:id (?resource) IN (",
-	                        event->subject_id);
-
-	for (i = 0; event->types[i] != 0; i++) {
-		gint32 rdf_type = event->types[i];
-
-		if (comma) {
-			g_string_append_printf (query, ", %d", rdf_type);
-		} else {
-			g_string_append_printf (query, "%d", rdf_type);
-			comma = TRUE;
-		}
-	}
-
-	g_string_append (query, ")) }");
+	query = g_string_new (NULL);
+	g_string_append_printf (query,
+				"SELECT ?type tracker:uri (%d) { "
+				"  ?resource a ?type . "
+				"  FILTER (tracker:id(?resource) = %d) "
+				"}",
+	                        event->subject_id, event->subject_id);
 
 	tracker_sparql_connection_query_async (priv->connection,
 	                                       query->str,
@@ -526,15 +505,9 @@ on_writeback_cb (GDBusConnection      *connection,
 
 	if (g_variant_iter_next (iter1, "{iai}", &subject_id, &iter2)) {
 		WritebackEvent *event = g_new (WritebackEvent, 1);
-		GArray *types = g_array_new (TRUE, TRUE, sizeof (gint32));
-		gint32 rdf_type;
-
-		while (g_variant_iter_loop (iter2, "i", &rdf_type))
-			g_array_append_val (types, rdf_type);
 
 		g_variant_iter_free (iter2);
 		event->subject_id = subject_id;
-		event->types = (gint32 *) g_array_free (types, FALSE);
 		g_queue_push_tail (priv->events, event);
 	}
 
