@@ -29,20 +29,14 @@
 
 #include "tracker-miner-rss.h"
 
-#define DBUS_NAME_SUFFIX "Tracker1.Miner.RSS"
-#define DBUS_PATH "/org/freedesktop/Tracker1/Miner/RSS"
+#define DBUS_NAME_SUFFIX "Tracker3.Miner.RSS"
+#define DBUS_PATH "/org/freedesktop/Tracker3/Miner/RSS"
 
-static gint verbosity = -1;
 static gchar *add_feed;
 static gchar *title;
 static gchar *domain_ontology_name = NULL;
 
 static GOptionEntry entries[] = {
-	{ "verbosity", 'v', 0,
-	  G_OPTION_ARG_INT, &verbosity,
-	  N_("Logging, 0 = errors only, "
-	  "1 = minimal, 2 = detailed and 3 = debug (default=0)"),
-	  NULL },
 	{ "add-feed", 'a', 0,
 	  G_OPTION_ARG_STRING, &add_feed,
 	  /* Translators: this is a "feed" as in RSS */
@@ -68,17 +62,73 @@ on_domain_vanished (GDBusConnection *connection,
 	g_main_loop_quit (loop);
 }
 
+TrackerSparqlConnectionFlags
+get_fts_connection_flags (void)
+{
+	TrackerSparqlConnectionFlags flags = 0;
+	TrackerFTSConfig *fts_config;
+
+	fts_config = tracker_fts_config_new ();
+
+	if (tracker_fts_config_get_enable_stemmer (fts_config))
+		flags |= TRACKER_SPARQL_CONNECTION_FLAGS_FTS_ENABLE_STEMMER;
+	if (tracker_fts_config_get_enable_unaccent (fts_config))
+		flags |= TRACKER_SPARQL_CONNECTION_FLAGS_FTS_ENABLE_UNACCENT;
+	if (tracker_fts_config_get_ignore_numbers (fts_config))
+		flags |= TRACKER_SPARQL_CONNECTION_FLAGS_FTS_IGNORE_NUMBERS;
+	if (tracker_fts_config_get_ignore_stop_words (fts_config))
+		flags |= TRACKER_SPARQL_CONNECTION_FLAGS_FTS_ENABLE_STOP_WORDS;
+
+	g_object_unref (fts_config);
+
+	return flags;
+}
+
+static gboolean
+setup_connection_and_endpoint (TrackerDomainOntology    *domain,
+                               GDBusConnection          *connection,
+                               TrackerSparqlConnection **sparql_conn,
+                               TrackerEndpointDBus     **endpoint,
+                               GError                  **error)
+{
+	GFile *cache, *store;
+
+	cache = tracker_domain_ontology_get_cache (domain);
+	store = g_file_get_child (cache, "rss");
+	*sparql_conn = tracker_sparql_connection_new (get_fts_connection_flags (),
+	                                              store,
+	                                              NULL,
+	                                              NULL,
+	                                              error);
+	g_object_unref (store);
+
+	if (!*sparql_conn)
+		return FALSE;
+
+	*endpoint = tracker_endpoint_dbus_new (*sparql_conn,
+	                                       connection,
+	                                       NULL,
+	                                       NULL,
+	                                       error);
+	if (!*endpoint)
+		return FALSE;
+
+	return TRUE;
+}
+
 int
 main (int argc, char **argv)
 {
-	gchar *log_filename;
 	GMainLoop *loop;
 	GOptionContext *context;
 	TrackerMinerRSS *miner;
 	GError *error = NULL;
 	GDBusConnection *connection;
+	TrackerSparqlConnection *sparql_conn;
+	TrackerEndpointDBus *endpoint;
 	TrackerMinerProxy *proxy;
-	gchar *dbus_domain_name, *dbus_name;
+	TrackerDomainOntology *domain_ontology;
+	gchar *domain_name, *dbus_name;
 
 	setlocale (LC_ALL, "");
 
@@ -107,8 +157,6 @@ main (int argc, char **argv)
 
 	g_option_context_free (context);
 
-	tracker_sparql_connection_set_domain (domain_ontology_name);
-
 	/* Command line stuff doesn't use logging, so we're using g_print*() */
 	if (add_feed) {
 		TrackerSparqlConnection *connection;
@@ -120,7 +168,8 @@ main (int argc, char **argv)
 		         title,
 		         add_feed);
 
-		connection = tracker_sparql_connection_get (NULL, &error);
+		connection = tracker_sparql_connection_bus_new ("org.freedesktop.Tracker3.Miner.RSS",
+		                                                NULL, NULL, &error);
 
 		if (!connection) {
 			g_printerr ("%s: %s\n",
@@ -165,14 +214,7 @@ main (int argc, char **argv)
 		return EXIT_SUCCESS;
 	}
 
-	tracker_log_init (verbosity, &log_filename);
-	if (log_filename != NULL) {
-		g_message ("Using log file:'%s'", log_filename);
-		g_free (log_filename);
-	}
-
-	tracker_load_domain_config (domain_ontology_name, &dbus_domain_name, &error);
-
+	domain_ontology = tracker_domain_ontology_new (domain_ontology_name, NULL, &error);
 	if (error) {
 		g_critical ("Could not load domain ontology '%s': %s",
 		            domain_ontology_name, error->message);
@@ -188,7 +230,20 @@ main (int argc, char **argv)
 		return EXIT_FAILURE;
 	}
 
-	miner = tracker_miner_rss_new (&error);
+	if (!setup_connection_and_endpoint (domain_ontology,
+	                                    connection,
+	                                    &sparql_conn,
+	                                    &endpoint,
+	                                    &error)) {
+
+		g_critical ("Could not create store/endpoint: %s",
+		            error->message);
+		g_error_free (error);
+
+		return EXIT_FAILURE;
+	}
+
+	miner = tracker_miner_rss_new (sparql_conn, &error);
 	if (!miner) {
 		g_critical ("Could not create new RSS miner: '%s', exiting...\n",
 		            error ? error->message : "unknown error");
@@ -203,7 +258,7 @@ main (int argc, char **argv)
 		return EXIT_FAILURE;
 	}
 
-	dbus_name = g_strconcat (dbus_domain_name, ".", DBUS_NAME_SUFFIX, NULL);
+	dbus_name = tracker_domain_ontology_get_domain (domain_ontology, DBUS_NAME_SUFFIX);
 
 	if (!tracker_dbus_request_name (connection, dbus_name, &error)) {
 		g_critical ("Could not request DBus name '%s': %s",
@@ -217,26 +272,29 @@ main (int argc, char **argv)
 
 	loop = g_main_loop_new (NULL, FALSE);
 
-	if (domain_ontology_name) {
+	if (domain_ontology && domain_ontology_name) {
 		/* If we are running for a specific domain, we tie the lifetime of this
 		 * process to the domain. For example, if the domain name is
 		 * org.example.MyApp then this tracker-miner-rss process will exit as
 		 * soon as org.example.MyApp exits.
 		 */
-		g_bus_watch_name_on_connection (connection, dbus_domain_name,
+		domain_name = tracker_domain_ontology_get_domain (domain_ontology, NULL);
+		g_bus_watch_name_on_connection (connection, domain_name,
 		                                G_BUS_NAME_WATCHER_FLAGS_NONE,
 		                                NULL, on_domain_vanished,
 		                                loop, NULL);
+		g_free (domain_name);
 	}
 
 	g_main_loop_run (loop);
 
-	tracker_log_shutdown ();
 	g_main_loop_unref (loop);
+	g_object_unref (sparql_conn);
+	g_object_unref (endpoint);
 	g_object_unref (miner);
 	g_object_unref (connection);
 	g_object_unref (proxy);
-	g_free (dbus_domain_name);
+	tracker_domain_ontology_unref (domain_ontology);
 
 	return EXIT_SUCCESS;
 }
