@@ -148,7 +148,7 @@ decorator_save_info (TrackerExtractDecorator *decorator,
                      TrackerExtractInfo      *info)
 {
 	const gchar *urn;
-	TrackerResource *resource = NULL;
+	TrackerResource *resource = NULL, *file_resource;
 
 	g_set_object (&resource, tracker_extract_info_get_resource (info));
 
@@ -163,10 +163,13 @@ decorator_save_info (TrackerExtractDecorator *decorator,
 	}
 
 	urn = tracker_decorator_info_get_urn (decorator_info);
-
 	tracker_resource_set_identifier (resource, urn);
-	tracker_resource_add_uri (resource, "nie:dataSource",
+
+	file_resource = tracker_resource_new (tracker_decorator_info_get_url (decorator_info));
+	tracker_resource_add_uri (file_resource, "rdf:type", "nfo:FileDataObject");
+	tracker_resource_add_uri (file_resource, "nie:dataSource",
 	        tracker_decorator_get_data_source (TRACKER_DECORATOR (decorator)));
+	tracker_resource_add_take_relation (resource, "nie:isStoredAs", file_resource);
 
 	return resource;
 }
@@ -180,6 +183,7 @@ get_metadata_cb (TrackerExtract *extract,
 	TrackerExtractInfo *info;
 	TrackerResource *resource;
 	GError *error = NULL;
+	const gchar *graph, *mime_type;
 	gchar *sparql;
 
 	priv = tracker_extract_decorator_get_instance_private (TRACKER_EXTRACT_DECORATOR (data->decorator));
@@ -192,17 +196,22 @@ get_metadata_cb (TrackerExtract *extract,
 		g_message ("Extraction failed: %s\n", error ? error->message : "no error given");
 		g_clear_error (&error);
 
-		sparql = g_strdup_printf ("INSERT DATA { GRAPH <" TRACKER_OWN_GRAPH_URN "> {"
+		mime_type = tracker_decorator_info_get_mimetype (data->decorator_info);
+		graph = tracker_extract_module_manager_get_graph (mime_type);
+
+		sparql = g_strdup_printf ("INSERT DATA { GRAPH %s {"
 		                          "  <%s> nie:dataSource <" TRACKER_EXTRACT_DATA_SOURCE ">;"
 		                          "       nie:dataSource <" TRACKER_EXTRACT_FAILURE_DATA_SOURCE ">."
-		                          "}}", tracker_decorator_info_get_urn (data->decorator_info));
+		                          "}}",
+		                          graph,
+		                          tracker_decorator_info_get_url (data->decorator_info));
 
 		tracker_decorator_info_complete (data->decorator_info, sparql);
 	} else {
 		resource = decorator_save_info (TRACKER_EXTRACT_DECORATOR (data->decorator),
 		                                data->decorator_info, info);
 		sparql = tracker_resource_print_sparql_update (resource, NULL,
-		                                               TRACKER_OWN_GRAPH_URN);
+		                                               tracker_extract_info_get_graph (info));
 		tracker_decorator_info_complete (data->decorator_info, sparql);
 		tracker_extract_info_unref (info);
 		g_object_unref (resource);
@@ -349,8 +358,8 @@ tracker_extract_decorator_items_available (TrackerDecorator *decorator)
 	TrackerExtractDecoratorPrivate *priv;
 
 	priv = tracker_extract_decorator_get_instance_private (TRACKER_EXTRACT_DECORATOR (decorator));
-	g_message ("Starting to process %d items",
-	           tracker_decorator_get_n_items (decorator));
+	g_debug ("Starting to process %d items",
+	         tracker_decorator_get_n_items (decorator));
 
 	priv->timer = g_timer_new ();
 	if (tracker_miner_is_paused (TRACKER_MINER (decorator)))
@@ -373,7 +382,7 @@ tracker_extract_decorator_finished (TrackerDecorator *decorator)
 	}
 
 	time_str = tracker_seconds_to_string (elapsed, TRUE);
-	g_message ("Extraction finished in %s", time_str);
+	g_debug ("Extraction finished in %s", time_str);
 	g_free (time_str);
 }
 
@@ -557,7 +566,8 @@ tracker_extract_decorator_class_init (TrackerExtractDecoratorClass *klass)
 	                                                      "Extractor",
 	                                                      TRACKER_TYPE_EXTRACT,
 	                                                      G_PARAM_READWRITE |
-	                                                      G_PARAM_CONSTRUCT_ONLY));
+	                                                      G_PARAM_CONSTRUCT_ONLY |
+	                                                      G_PARAM_STATIC_STRINGS));
 }
 
 static void
@@ -581,17 +591,34 @@ decorator_ignore_file (GFile    *file,
 	TrackerSparqlConnection *conn;
 	GError *error = NULL;
 	gchar *uri, *query;
+	const gchar *mimetype, *graph;
+	GFileInfo *info;
 
 	uri = g_file_get_uri (file);
 	g_message ("Extraction on file '%s' has been attempted too many times, ignoring", uri);
 
+	info = g_file_query_info (file,
+	                          G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE,
+	                          G_FILE_QUERY_INFO_NOFOLLOW_SYMLINKS,
+	                          NULL, &error);
+	if (!info) {
+		g_warning ("Could not get mimetype: %s", error->message);
+		g_error_free (error);
+		return;
+	}
+
+	mimetype = g_file_info_get_attribute_string (info,
+	                                             G_FILE_ATTRIBUTE_STANDARD_CONTENT_TYPE);
+	graph = tracker_extract_module_manager_get_graph (mimetype);
+	g_object_unref (info);
+
 	conn = tracker_miner_get_connection (TRACKER_MINER (decorator));
-	query = g_strdup_printf ("INSERT { GRAPH <" TRACKER_OWN_GRAPH_URN "> {"
-	                         "  ?urn nie:dataSource <" TRACKER_EXTRACT_DATA_SOURCE ">;"
+	query = g_strdup_printf ("INSERT DATA { GRAPH %s {"
+	                         "  <%s> nie:dataSource <" TRACKER_EXTRACT_DATA_SOURCE ">;"
 	                         "       nie:dataSource <" TRACKER_EXTRACT_FAILURE_DATA_SOURCE ">."
-	                         "} } WHERE {"
-	                         "  ?urn nie:url \"%s\""
-	                         "}", uri);
+	                         "}}",
+	                         graph,
+	                         uri);
 
 	tracker_sparql_connection_update (conn, query, G_PRIORITY_DEFAULT, NULL, &error);
 
@@ -653,7 +680,7 @@ tracker_extract_decorator_initable_init (GInitable     *initable,
 
 	if (!g_dbus_interface_skeleton_export (G_DBUS_INTERFACE_SKELETON (priv->iface),
 	                                       conn,
-	                                       "/org/freedesktop/Tracker1/Extract/Priority",
+	                                       "/org/freedesktop/Tracker3/Extract/Priority",
 	                                       error)) {
 		ret = FALSE;
 		goto out;
@@ -683,12 +710,14 @@ tracker_extract_decorator_initable_iface_init (GInitableIface *iface)
 }
 
 TrackerDecorator *
-tracker_extract_decorator_new (TrackerExtract  *extract,
-                               GCancellable    *cancellable,
-                               GError         **error)
+tracker_extract_decorator_new (TrackerSparqlConnection  *connection,
+                               TrackerExtract           *extract,
+                               GCancellable             *cancellable,
+                               GError                  **error)
 {
 	return g_initable_new (TRACKER_TYPE_EXTRACT_DECORATOR,
 	                       cancellable, error,
+	                       "connection", connection,
 	                       "data-source", TRACKER_EXTRACT_DATA_SOURCE,
 	                       "class-names", supported_classes,
 	                       "extractor", extract,
