@@ -55,39 +55,6 @@
 
 #include "tracker-cue-sheet.h"
 
-/* We wait this long (seconds) for NULL state before freeing */
-#define TRACKER_EXTRACT_GUARD_TIMEOUT 3
-
-/* An additional tag in gstreamer for the content source. Remove when in upstream */
-#ifndef GST_TAG_CLASSIFICATION
-#define GST_TAG_CLASSIFICATION "classification"
-#endif
-
-/* Some additional tagreadbin tags (FIXME until they are defined upstream)*/
-#ifndef GST_TAG_CHANNEL
-#define GST_TAG_CHANNEL "channels"
-#endif
-
-#ifndef GST_TAG_RATE
-#define GST_TAG_RATE "rate"
-#endif
-
-#ifndef GST_TAG_WIDTH
-#define GST_TAG_WIDTH "width"
-#endif
-
-#ifndef GST_TAG_HEIGHT
-#define GST_TAG_HEIGHT "height"
-#endif
-
-#ifndef GST_TAG_PIXEL_RATIO
-#define GST_TAG_PIXEL_RATIO "pixel-aspect-ratio"
-#endif
-
-#ifndef GST_TAG_FRAMERATE
-#define GST_TAG_FRAMERATE "framerate"
-#endif
-
 typedef enum {
 	EXTRACT_MIME_AUDIO,
 	EXTRACT_MIME_VIDEO,
@@ -352,7 +319,7 @@ get_embedded_cue_sheet_data (GstTagList *tag_list)
 			 * not have to jump past cuesheet= on the
 			 * returned value.
 			 */
-			g_memmove (buffer, buffer + 9, strlen ((gchar *) buffer + 9) + 1);
+			memmove (buffer, buffer + 9, strlen ((gchar *) buffer + 9) + 1);
 
 			return buffer;
 		}
@@ -653,8 +620,6 @@ extractor_apply_video_metadata (MetadataExtractor *extractor,
                                 TrackerResource   *performer,
                                 TrackerResource   *composer)
 {
-	set_property_from_gst_tag (video, "dc:source", tag_list, GST_TAG_CLASSIFICATION);
-
 	if (performer) {
 		tracker_resource_set_relation (video, "nmm:leadActor", performer);
 	}
@@ -666,21 +631,18 @@ extractor_apply_video_metadata (MetadataExtractor *extractor,
 	set_keywords_from_gst_tag (video, tag_list);
 }
 
-static TrackerResource *
-extract_track (MetadataExtractor    *extractor,
+static void
+extract_track (TrackerResource      *track,
+               MetadataExtractor    *extractor,
                TrackerTocEntry      *toc_entry,
                const gchar          *file_url,
                TrackerResource      *album_disc)
 {
-	TrackerResource *track;
 	TrackerResource *track_performer = NULL, *track_composer = NULL;
-	gchar *track_uri;
-
-	track_uri = tracker_sparql_get_uuid_urn ();
-	track = tracker_resource_new (track_uri);
 
 	tracker_resource_add_uri (track, "rdf:type", "nmm:MusicPiece");
 	tracker_resource_add_uri (track, "rdf:type", "nfo:Audio");
+	tracker_resource_add_string (track, "nie:generator", TRACKER_PREFIX_TRACKER "extractor-data-source");
 
 	extractor_apply_general_metadata (extractor,
 	                                  toc_entry->tag_list,
@@ -709,10 +671,6 @@ extract_track (MetadataExtractor    *extractor,
 	}
 
 	tracker_resource_set_double (track, "nfo:audioOffset", toc_entry->start);
-
-	g_free (track_uri);
-
-	return track;
 }
 
 #define CHUNK_N_BYTES (2 << 15)
@@ -885,16 +843,27 @@ extract_metadata (MetadataExtractor      *extractor,
 			 * concrete nfo:FileDataObject using nie:isStoredAs.
 			 */
 			if (extractor->toc && g_list_length (extractor->toc->entry_list) > 1) {
+				TrackerResource *file_resource;
+
+				file_resource = tracker_resource_new (file_url);
+
 				for (node = extractor->toc->entry_list; node; node = node->next) {
 					TrackerResource *track;
 
-					track = extract_track (extractor, node->data, file_url, album_disc);
-					tracker_resource_set_relation (track, "nie:isStoredAs", resource);
-					tracker_resource_set_relation (track, "nie:isLogicalPartOf", resource);
-					tracker_resource_add_take_relation (resource, "nie:hasLogicalPart", track);
+					/* Reuse the "root" InformationElement resource for the first track,
+					 * so there's no spare ones.
+					 */
+					if (node == extractor->toc->entry_list)
+						track = resource;
+					else
+						track = tracker_resource_new (NULL);
+
+					extract_track (track, extractor, node->data, file_url, album_disc);
+					tracker_resource_set_relation (track, "nie:isStoredAs", file_resource);
+					tracker_resource_add_take_relation (file_resource, "nie:interpretedAs", track);
 				}
 
-				tracker_resource_set_string (resource, "nie:url", file_url);
+				g_object_unref (file_resource);
 			} else {
 				extractor_apply_audio_metadata (extractor,
 				                                extractor->tagcache,
@@ -919,7 +888,7 @@ extract_metadata (MetadataExtractor      *extractor,
 		g_object_unref (file);
 
 		if (hash) {
-			TrackerResource *hash_resource;
+			TrackerResource *file_resource, *hash_resource;
 			char *hash_str;
 
 			hash_resource = tracker_resource_new (NULL);
@@ -931,7 +900,10 @@ extract_metadata (MetadataExtractor      *extractor,
 
 			tracker_resource_set_string (hash_resource, "nfo:hashAlgorithm", "gibest");
 
-			tracker_resource_set_relation (resource, "nfo:hasHash", hash_resource);
+			file_resource = tracker_resource_new (file_url);
+			tracker_resource_add_take_relation (resource, "nie:isStoredAs", file_resource);
+
+			tracker_resource_set_relation (file_resource, "nfo:hasHash", hash_resource);
 
 			g_object_unref (hash_resource);
 		}
