@@ -45,8 +45,6 @@
 
 G_DEFINE_QUARK (TrackerExtractError, tracker_extract_error)
 
-#define DEADLINE_SECONDS 30
-
 extern gboolean debug;
 
 typedef struct {
@@ -72,7 +70,6 @@ typedef struct {
 	GHashTable *single_thread_extractors;
 
 	gboolean disable_shutdown;
-	gboolean disable_summary_on_finalize;
 
 	gchar *force_module;
 
@@ -85,20 +82,17 @@ typedef struct {
 	GAsyncResult *res;
 	gchar *file;
 	gchar *mimetype;
+	const gchar *graph;
 
-	TrackerMimetypeInfo *mimetype_handlers;
-
-	/* to be fed from mimetype_handlers */
-	TrackerExtractMetadataFunc cur_func;
-	GModule *cur_module;
+	TrackerExtractMetadataFunc func;
+	GModule *module;
 
 	guint signal_id;
-	guint timeout_id;
 	guint success : 1;
 } TrackerExtractTask;
 
 static void tracker_extract_finalize (GObject *object);
-static void report_statistics        (GObject *object);
+static void log_statistics        (GObject *object);
 static gboolean get_metadata         (TrackerExtractTask *task);
 static gboolean dispatch_task_cb     (TrackerExtractTask *task);
 
@@ -127,12 +121,17 @@ tracker_extract_init (TrackerExtract *object)
 	TrackerExtractPrivate *priv;
 
 	priv = TRACKER_EXTRACT_GET_PRIVATE (object);
-	priv->statistics_data = g_hash_table_new_full (NULL, NULL, NULL,
-	                                               (GDestroyNotify) statistics_data_free);
 	priv->single_thread_extractors = g_hash_table_new (NULL, NULL);
 	priv->thread_pool = g_thread_pool_new ((GFunc) get_metadata,
 	                                       NULL, 10, TRUE, NULL);
 
+#ifdef G_ENABLE_DEBUG
+	if (TRACKER_DEBUG_CHECK (STATISTICS)) {
+		priv->statistics_data = g_hash_table_new_full (NULL, NULL, NULL,
+		                                               (GDestroyNotify) statistics_data_free);
+	}
+#endif
+
 	g_mutex_init (&priv->task_mutex);
 }
 
@@ -148,11 +147,13 @@ tracker_extract_finalize (GObject *object)
 	g_hash_table_destroy (priv->single_thread_extractors);
 	g_thread_pool_free (priv->thread_pool, TRUE, FALSE);
 
-	if (!priv->disable_summary_on_finalize) {
-		report_statistics (object);
-	}
+	log_statistics (object);
 
-	g_hash_table_destroy (priv->statistics_data);
+#ifdef G_ENABLE_DEBUG
+	if (TRACKER_DEBUG_CHECK (STATISTICS)) {
+		g_hash_table_destroy (priv->statistics_data);
+	}
+#endif
 
 	g_mutex_clear (&priv->task_mutex);
 
@@ -160,48 +161,52 @@ tracker_extract_finalize (GObject *object)
 }
 
 static void
-report_statistics (GObject *object)
+log_statistics (GObject *object)
 {
-	TrackerExtractPrivate *priv;
-	GHashTableIter iter;
-	gpointer key, value;
+#ifdef G_ENABLE_DEBUG
+	if (TRACKER_DEBUG_CHECK (STATISTICS)) {
+		TrackerExtractPrivate *priv;
+		GHashTableIter iter;
+		gpointer key, value;
 
-	priv = TRACKER_EXTRACT_GET_PRIVATE (object);
+		priv = TRACKER_EXTRACT_GET_PRIVATE (object);
 
-	g_mutex_lock (&priv->task_mutex);
+		g_mutex_lock (&priv->task_mutex);
 
-	g_message ("--------------------------------------------------");
-	g_message ("Statistics:");
+		g_message ("--------------------------------------------------");
+		g_message ("Statistics:");
 
-	g_hash_table_iter_init (&iter, priv->statistics_data);
+		g_hash_table_iter_init (&iter, priv->statistics_data);
 
-	while (g_hash_table_iter_next (&iter, &key, &value)) {
-		GModule *module = key;
-		StatisticsData *data = value;
+		while (g_hash_table_iter_next (&iter, &key, &value)) {
+			GModule *module = key;
+			StatisticsData *data = value;
 
-		if (data->extracted_count > 0 || data->failed_count > 0) {
-			const gchar *name, *name_without_path;
+			if (data->extracted_count > 0 || data->failed_count > 0) {
+				const gchar *name, *name_without_path;
 
-			name = g_module_name (module);
-			name_without_path = strrchr (name, G_DIR_SEPARATOR) + 1;
+				name = g_module_name (module);
+				name_without_path = strrchr (name, G_DIR_SEPARATOR) + 1;
 
-			g_message ("    Module:'%s', extracted:%d, failures:%d",
-			           name_without_path,
-			           data->extracted_count,
-			           data->failed_count);
+				g_message ("    Module:'%s', extracted:%d, failures:%d",
+				           name_without_path,
+				           data->extracted_count,
+				           data->failed_count);
+			}
 		}
+
+		g_message ("Unhandled files: %d", priv->unhandled_count);
+
+		if (priv->unhandled_count == 0 &&
+		    g_hash_table_size (priv->statistics_data) < 1) {
+			g_message ("    No files handled");
+		}
+
+		g_message ("--------------------------------------------------");
+
+		g_mutex_unlock (&priv->task_mutex);
 	}
-
-	g_message ("Unhandled files: %d", priv->unhandled_count);
-
-	if (priv->unhandled_count == 0 &&
-	    g_hash_table_size (priv->statistics_data) < 1) {
-		g_message ("    No files handled");
-	}
-
-	g_message ("--------------------------------------------------");
-
-	g_mutex_unlock (&priv->task_mutex);
+#endif
 }
 
 TrackerExtract *
@@ -242,25 +247,29 @@ notify_task_finish (TrackerExtractTask *task,
 	 */
 	g_mutex_lock (&priv->task_mutex);
 
-	if (task->cur_module) {
-		stats_data = g_hash_table_lookup (priv->statistics_data,
-						  task->cur_module);
+#ifdef G_ENABLE_DEBUG
+	if (TRACKER_DEBUG_CHECK (STATISTICS)) {
+		if (task->module) {
+			stats_data = g_hash_table_lookup (priv->statistics_data,
+			                                  task->module);
 
-		if (!stats_data) {
-			stats_data = g_slice_new0 (StatisticsData);
-			g_hash_table_insert (priv->statistics_data,
-					     task->cur_module,
-					     stats_data);
+			if (!stats_data) {
+				stats_data = g_slice_new0 (StatisticsData);
+				g_hash_table_insert (priv->statistics_data,
+				                     task->module,
+				                     stats_data);
+			}
+
+			stats_data->extracted_count++;
+
+			if (!success) {
+				stats_data->failed_count++;
+			}
+		} else {
+			priv->unhandled_count++;
 		}
-
-		stats_data->extracted_count++;
-
-		if (!success) {
-			stats_data->failed_count++;
-		}
-	} else {
-		priv->unhandled_count++;
 	}
+#endif
 
 	priv->running_tasks = g_list_remove (priv->running_tasks, task);
 
@@ -278,7 +287,7 @@ get_file_metadata (TrackerExtractTask  *task,
 	*info_out = NULL;
 
 	file = g_file_new_for_uri (task->file);
-	info = tracker_extract_info_new (file, task->mimetype);
+	info = tracker_extract_info_new (file, task->mimetype, task->graph);
 	g_object_unref (file);
 
 	if (task->mimetype && *task->mimetype) {
@@ -293,13 +302,13 @@ get_file_metadata (TrackerExtractTask  *task,
 	 * data we need from the extractors.
 	 */
 	if (mime_used) {
-		if (task->cur_func) {
+		if (task->func) {
 			g_debug ("Using %s...",
-				 task->cur_module ?
-				 g_module_name (task->cur_module) :
+				 task->module ?
+				 g_module_name (task->module) :
 				 "Dummy extraction");
 
-			task->success = (task->cur_func) (info);
+			task->success = (task->func) (info);
 		}
 
 		g_free (mime_used);
@@ -338,19 +347,6 @@ task_cancellable_cancelled_cb (GCancellable       *cancellable,
 	g_mutex_unlock (&priv->task_mutex);
 }
 
-static gboolean
-task_deadline_cb (gpointer user_data)
-{
-	TrackerExtractTask *task = user_data;
-
-	g_warning ("File '%s' took too long to process. Shutting down everything",
-	           task->file);
-
-	if (task->cancellable)
-		g_cancellable_cancel (task->cancellable);
-	_exit (0);
-}
-
 static TrackerExtractTask *
 extract_task_new (TrackerExtract *extract,
                   const gchar    *uri,
@@ -396,15 +392,6 @@ extract_task_new (TrackerExtract *extract,
 	task->mimetype = mimetype_used;
 	task->extract = extract;
 
-	if (task->res) {
-		GSource *source;
-
-		source = g_timeout_source_new_seconds (DEADLINE_SECONDS);
-		g_source_set_callback (source, task_deadline_cb, task, NULL);
-		task->timeout_id =
-			g_source_attach (source, g_task_get_context (G_TASK (task->res)));
-	}
-
 	if (task->cancellable) {
 		task->signal_id = g_cancellable_connect (cancellable,
 		                                         G_CALLBACK (task_cancellable_cancelled_cb),
@@ -423,9 +410,6 @@ extract_task_free (TrackerExtractTask *task)
 
 	notify_task_finish (task, task->success);
 
-	if (task->timeout_id)
-		g_source_remove (task->timeout_id);
-
 	if (task->res) {
 		g_object_unref (task->res);
 	}
@@ -434,10 +418,6 @@ extract_task_free (TrackerExtractTask *task)
 		g_object_unref (task->cancellable);
 	}
 
-	if (task->mimetype_handlers) {
-		tracker_mimetype_info_free (task->mimetype_handlers);
-	}
-
 	g_free (task->mimetype);
 	g_free (task->file);
 
@@ -507,16 +487,18 @@ get_metadata (TrackerExtractTask *task)
 		return FALSE;
 	}
 
-	if (!filter_module (task->extract, task->cur_module) &&
+	if (!filter_module (task->extract, task->module) &&
 	    get_file_metadata (task, &info)) {
 		g_task_return_pointer (G_TASK (task->res), info,
 		                       (GDestroyNotify) tracker_extract_info_unref);
 		extract_task_free (task);
 	} else {
-		/* Reinject the task into the main thread
-		 * queue, so the next module kicks in.
-		 */
-		g_idle_add ((GSourceFunc) dispatch_task_cb, task);
+		g_task_return_new_error (G_TASK (task->res),
+		                         tracker_extract_error_quark (),
+		                         TRACKER_EXTRACT_ERROR_NO_EXTRACTOR,
+		                         "Could not get any metadata for uri:'%s' and mime:'%s'",
+		                         task->file, task->mimetype);
+		extract_task_free (task);
 	}
 
 	return FALSE;
@@ -552,7 +534,6 @@ dispatch_task_cb (TrackerExtractTask *task)
 	TrackerExtractPrivate *priv;
 	GError *error = NULL;
 	GAsyncQueue *async_queue;
-	GModule *module;
 
 #ifdef THREAD_ENABLE_TRACE
 	g_debug ("Thread:%p (Main) <-- '%s': Handling task...\n",
@@ -567,30 +548,14 @@ dispatch_task_cb (TrackerExtractTask *task)
 		                     TRACKER_EXTRACT_ERROR_NO_MIMETYPE,
 		                     "No mimetype for '%s'", task->file);
 	} else {
-		if (!task->mimetype_handlers) {
-			/* First iteration for task, get the mimetype handlers */
-			task->mimetype_handlers = tracker_extract_module_manager_get_mimetype_handlers (task->mimetype);
-
-			if (!task->mimetype_handlers) {
-				error = g_error_new (tracker_extract_error_quark (),
-				                     TRACKER_EXTRACT_ERROR_NO_EXTRACTOR,
-				                     "No mimetype extractor handlers for uri:'%s' and mime:'%s'",
-				                     task->file, task->mimetype);
-			}
-		} else {
-			/* Any further iteration, should happen rarely if
-			 * most specific handlers know nothing about the file
-			 */
-			if (!tracker_mimetype_info_iter_next (task->mimetype_handlers)) {
-				g_message ("There's no next extractor");
-
-				error = g_error_new (tracker_extract_error_quark (),
-				                     TRACKER_EXTRACT_ERROR_NO_EXTRACTOR,
-				                     "Could not get any metadata for uri:'%s' and mime:'%s'",
-				                     task->file, task->mimetype);
-			} else {
-				g_message ("Trying next extractor for '%s'", task->file);
-			}
+		task->module = tracker_extract_module_manager_get_module (task->mimetype,
+		                                                          NULL,
+		                                                          &task->func);
+		if (!task->module) {
+			error = g_error_new (tracker_extract_error_quark (),
+			                     TRACKER_EXTRACT_ERROR_NO_EXTRACTOR,
+			                     "No mimetype extractor handlers for uri:'%s' and mime:'%s'",
+			                     task->file, task->mimetype);
 		}
 	}
 
@@ -601,16 +566,10 @@ dispatch_task_cb (TrackerExtractTask *task)
 		return FALSE;
 	}
 
-	task->cur_module = module = tracker_mimetype_info_get_module (task->mimetype_handlers, &task->cur_func);
+	task->graph = tracker_extract_module_manager_get_graph (task->mimetype);
 
-	if (!task->cur_func) {
-		g_warning ("Discarding task, no module able to handle '%s'", task->file);
-		priv->unhandled_count++;
-		extract_task_free (task);
-		return FALSE;
-	}
-
-	async_queue = g_hash_table_lookup (priv->single_thread_extractors, module);
+	async_queue = g_hash_table_lookup (priv->single_thread_extractors,
+	                                   task->module);
 
 	if (!async_queue) {
 		GThread *thread;
@@ -632,7 +591,7 @@ dispatch_task_cb (TrackerExtractTask *task)
 		/* We won't join the thread, so just unref it here */
 		g_thread_unref (thread);
 
-		g_hash_table_insert (priv->single_thread_extractors, module, async_queue);
+		g_hash_table_insert (priv->single_thread_extractors, task->module, async_queue);
 	}
 
 	g_async_queue_push (async_queue, task);
@@ -694,13 +653,9 @@ tracker_extract_get_metadata_by_cmdline (TrackerExtract             *object,
                                          TrackerSerializationFormat  output_format)
 {
 	GError *error = NULL;
-	TrackerExtractPrivate *priv;
 	TrackerExtractTask *task;
 	TrackerExtractInfo *info;
-	gboolean no_data_or_modules = TRUE;
-
-	priv = TRACKER_EXTRACT_GET_PRIVATE (object);
-	priv->disable_summary_on_finalize = TRUE;
+	TrackerResource *resource = NULL;
 
 	g_return_if_fail (uri != NULL);
 
@@ -715,77 +670,59 @@ tracker_extract_get_metadata_by_cmdline (TrackerExtract             *object,
 		return;
 	}
 
-	task->mimetype_handlers = tracker_extract_module_manager_get_mimetype_handlers (task->mimetype);
-	if (task->mimetype_handlers) {
-		task->cur_module = tracker_mimetype_info_get_module (task->mimetype_handlers, &task->cur_func);
+	task->module = tracker_extract_module_manager_get_module (task->mimetype,
+	                                                          NULL,
+	                                                          &task->func);
+
+	if (!filter_module (object, task->module) &&
+	    get_file_metadata (task, &info)) {
+		resource = tracker_extract_info_get_resource (info);
 	}
 
-	while (task->cur_func) {
-		if (!filter_module (object, task->cur_module) &&
-		    get_file_metadata (task, &info)) {
-			TrackerResource *resource = tracker_extract_info_get_resource (info);
+	if (resource) {
+		if (output_format == TRACKER_SERIALIZATION_FORMAT_SPARQL) {
+			char *text;
 
-			if (resource == NULL)
-				break;
+			/* If this was going into the tracker-store we'd generate a unique ID
+			 * here, so that the data persisted across file renames.
+			 */
+			tracker_resource_set_identifier (resource, uri);
 
-			no_data_or_modules = FALSE;
+			text = tracker_resource_print_sparql_update (resource, NULL, NULL);
 
-			if (output_format == TRACKER_SERIALIZATION_FORMAT_SPARQL) {
-				char *text;
+			g_print ("%s\n", text);
 
-				/* If this was going into the tracker-store we'd generate a unique ID
-				 * here, so that the data persisted across file renames.
-				 */
-				tracker_resource_set_identifier (resource, uri);
+			g_free (text);
+		} else if (output_format == TRACKER_SERIALIZATION_FORMAT_TURTLE) {
+			char *turtle;
 
-				text = tracker_resource_print_sparql_update (resource, NULL, NULL);
+			/* If this was going into the tracker-store we'd generate a unique ID
+			 * here, so that the data persisted across file renames.
+			 */
+			tracker_resource_set_identifier (resource, uri);
 
-				g_print ("%s\n", text);
+			turtle = tracker_resource_print_turtle (resource, NULL);
 
-				g_free (text);
-			} else if (output_format == TRACKER_SERIALIZATION_FORMAT_TURTLE) {
-				char *turtle;
-
-				/* If this was going into the tracker-store we'd generate a unique ID
-				 * here, so that the data persisted across file renames.
-				 */
-				tracker_resource_set_identifier (resource, uri);
-
-				turtle = tracker_resource_print_turtle (resource, NULL);
-
-				if (turtle) {
-					g_print ("%s\n", turtle);
-					g_free (turtle);
-				}
-			} else {
-				/* JSON-LD extraction */
-				char *json;
-
-				/* If this was going into the tracker-store we'd generate a unique ID
-				 * here, so that the data persisted across file renames.
-				 */
-				tracker_resource_set_identifier (resource, uri);
-
-				json = tracker_resource_print_jsonld (resource, NULL);
-				if (json) {
-					g_print ("%s\n", json);
-					g_free (json);
-				}
+			if (turtle) {
+				g_print ("%s\n", turtle);
+				g_free (turtle);
 			}
-
-			tracker_extract_info_unref (info);
-			break;
 		} else {
-			if (!tracker_mimetype_info_iter_next (task->mimetype_handlers)) {
-				break;
+			/* JSON-LD extraction */
+			char *json;
+
+			/* If this was going into the tracker-store we'd generate a unique ID
+			 * here, so that the data persisted across file renames.
+			 */
+			tracker_resource_set_identifier (resource, uri);
+
+			json = tracker_resource_print_jsonld (resource, NULL);
+			if (json) {
+				g_print ("%s\n", json);
+				g_free (json);
 			}
-
-			task->cur_module = tracker_mimetype_info_get_module (task->mimetype_handlers,
-			                                                     &task->cur_func);
 		}
-	}
-
-	if (no_data_or_modules) {
+	} else {
 		g_printerr ("%s: %s\n",
 		         uri,
 		         _("No metadata or extractor modules found to handle this file"));
